PALM-meteo: palmmeteo_stdplugins.cams Namespace Reference

PALM-meteo

Loading...
Searching...
No Matches
Classes | Variables
palmmeteo_stdplugins.cams Namespace Reference

## Classes
class | CAMSPlugin

## Variables
| ax_ = np.newaxis
| re_num = re.compile(r'[0-9\.]+')
| re_lev = re.compile(r'^.* at ([\d\.]+) meters above the surface.*$')
| re_time_nonst = re.compile(r'^.* time from (\d{8})$')

## Variable Documentation

## ◆ ax_

palmmeteo_stdplugins.cams.ax_ = np.newaxis

## ◆ re_lev

palmmeteo_stdplugins.cams.re_lev = re.compile(r'^.* at ([\d\.]+) meters above the surface.*$')

## ◆ re_num

palmmeteo_stdplugins.cams.re_num = re.compile(r'[0-9\.]+')

## ◆ re_time_nonst

palmmeteo_stdplugins.cams.re_time_nonst = re.compile(r'^.* time from (\d{8})$')